# Covid-19 model

Package for epidemiologic modelling of dieseases like Covid-19.

It includes

- compartmental models (SIR model + SIRS model with vaccination and seasonality)
- solving algorithm
- visualization
